@@ -7,6 +7,7 @@ import logging.config
 from dataclasses import dataclass
 from datetime import datetime
 from enum import Enum
+from io import BytesIO
 from typing import Optional, Any, Union, List, Dict
 
 from dateutil.parser import parse
@@ -19,6 +20,10 @@ logging.basicConfig(
 )
 
 
+class QueryFailed(Exception):
+    """Special Error for failed Queries"""
+
+
 class DuneError(Exception):
     """Possibilities seen so far
     {'error': 'invalid API Key'}
@@ -51,6 +56,10 @@ class ExecutionState(Enum):
         """
         return {cls.COMPLETED, cls.CANCELLED, cls.FAILED}
 
+    def is_complete(self) -> bool:
+        """Returns True is state is completed, otherwise False."""
+        return self == ExecutionState.COMPLETED
+
 
 @dataclass
 class ExecutionResponse:
@@ -168,6 +177,18 @@ RowData = List[Dict[str, str]]
 MetaData = Dict[str, Union[int, List[str]]]
 
 
+@dataclass
+class ExecutionResultCSV:
+    """
+    Representation of a raw `result` in CSV format
+    this payload can be passed directly to
+        csv.reader(data) or
+        pandas.from_csv(data)
+    """
+
+    data: BytesIO  # includes all CSV rows, including the header row.
+
+
 @dataclass
 class ExecutionResult:
     """Representation of `result` field of a Dune ResultsResponse"""
