@@ -10,12 +10,11 @@ from datetime import datetime
 from enum import Enum
 from typing import Any, Dict
 
-from web3 import Web3
-
 from dune_client.util import postgres_date
 
 DuneRecord = Dict[str, str]
 
+
 # pylint: disable=too-few-public-methods
 class Address:
     """
@@ -31,7 +30,7 @@ class Address:
         # so they don't have to convert all addresses to hex strings manually
         address = address.replace("\\x", "0x")
         if Address._is_valid(address):
-            self.address: str = Web3.toChecksumAddress(address)
+            self.address: str = address.lower()
         else:
             raise ValueError(f"Invalid Ethereum Address {address}")
 
@@ -159,9 +158,9 @@ class QueryParameter:
             return str(self.value.strftime("%Y-%m-%d %H:%M:%S"))
         raise TypeError(f"Type {self.type} not recognized!")
 
-    def to_dict(self) -> dict[str, str | list[str]]:
+    def to_dict(self) -> dict[str, str]:
         """Converts QueryParameter into string json format accepted by Dune API"""
-        results: dict[str, str | list[str]] = {
+        results: dict[str, str] = {
             "key": self.key,
             "type": self.type.value,
             "value": self.value_str(),
@@ -190,9 +189,13 @@ class QueryParameter:
         raise ValueError(f"Could not parse Query parameter from {obj}")
 
     def __str__(self) -> str:
+        # For less cryptic logging.
         return (
-            f"QueryParameter("
-            f"name: {self.key}, "
-            f"value: {self.value}, "
-            f"type: {self.type.value})"
+            f"Parameter("
+            f"name={self.key}, "
+            f"value={self.value}, "
+            f"type={self.type.value})"
         )
+
+    def __repr__(self) -> str:
+        return str(self)
