@@ -36,13 +36,20 @@ class TestDuneClient(unittest.TestCase):
         dune = DuneClient(self.valid_api_key)
         job_id = dune.execute(query).execution_id
         status = dune.get_status(job_id)
-        self.assertEqual(status.state, ExecutionState.EXECUTING)
+        self.assertTrue(
+            status.state in [ExecutionState.EXECUTING, ExecutionState.PENDING]
+        )
 
     def test_refresh(self):
         dune = DuneClient(self.valid_api_key)
-        results = dune.refresh(self.query)
+        results = dune.refresh(self.query).get_rows()
         self.assertGreater(len(results), 0)
 
+    def test_refresh_into_dataframe(self):
+        dune = DuneClient(self.valid_api_key)
+        pd = dune.refresh_into_dataframe(self.query)
+        self.assertGreater(len(pd), 0)
+
     def test_parameters_recognized(self):
         query = copy.copy(self.query)
         new_params = [
@@ -58,12 +65,12 @@ class TestDuneClient(unittest.TestCase):
         dune = DuneClient(self.valid_api_key)
         results = dune.refresh(query)
         self.assertEqual(
-            results,
+            results.get_rows(),
             [
                 {
                     "text_field": "different word",
-                    "number_field": "22",
-                    "date_field": "1991-01-01 00:00:00",
+                    "number_field": 22,
+                    "date_field": "1991-01-01T00:00:00",
                     "list_field": "Option 2",
                 }
             ],
@@ -88,10 +95,14 @@ class TestDuneClient(unittest.TestCase):
             query_id=1229120,
         )
         execution_response = dune.execute(query)
+        job_id = execution_response.execution_id
         # POST Cancellation
-        success = dune.cancel_execution(execution_response.execution_id)
+        success = dune.cancel_execution(job_id)
         self.assertTrue(success)
 
+        results = dune.get_result(job_id)
+        self.assertEqual(results.state, ExecutionState.CANCELLED)
+
     def test_invalid_api_key_error(self):
         dune = DuneClient(api_key="Invalid Key")
         with self.assertRaises(DuneError) as err:
@@ -135,7 +146,7 @@ class TestDuneClient(unittest.TestCase):
             dune.execute(query)
         self.assertEqual(
             str(err.exception),
-            "Can't build ExecutionResponse from {'error': 'An internal error occured'}",
+            "Can't build ExecutionResponse from {'error': 'Query not found'}",
         )
 
     def test_invalid_job_id_error(self):
