@@ -1,17 +1,21 @@
 import unittest
+import csv
 from datetime import datetime
+from io import BytesIO, TextIOWrapper
 
 from dateutil.parser import parse
 from dateutil.tz import tzutc
 
 from dune_client.models import (
     ExecutionResponse,
+    ExecutionResultCSV,
     ExecutionStatusResponse,
     ExecutionState,
     ResultsResponse,
     TimeData,
     ExecutionResult,
     ResultMetadata,
+    DuneError,
 )
 
 
@@ -68,6 +72,12 @@ class MyTestCase(unittest.TestCase):
                 "metadata": self.result_metadata_data,
             },
         }
+        self.execution_result_csv_data = BytesIO(
+            b"""TableName,ct
+eth_blocks,6296
+eth_traces,4474223
+""",
+        )
 
     def test_execution_response_parsing(self):
         expected = ExecutionResponse(
@@ -115,6 +125,29 @@ class MyTestCase(unittest.TestCase):
             expected, ExecutionStatusResponse.from_dict(self.status_response_data)
         )
 
+    def test_parse_known_status_response(self):
+        # For context: https://github.com/cowprotocol/dune-client/issues/22
+        response = {
+            "execution_id": "01GES18035K5C4GDTY12Q79GBD",
+            "query_id": 1317323,
+            "state": "QUERY_STATE_COMPLETED",
+            "submitted_at": "2022-10-07T10:53:18.822127Z",
+            "expires_at": "2024-10-06T10:53:20.729373Z",
+            "execution_started_at": "2022-10-07T10:53:18.823105936Z",
+            "execution_ended_at": "2022-10-07T10:53:20.729372559Z",
+            "result_metadata": {
+                "column_names": ["token"],
+                "result_set_bytes": 815,
+                "total_row_count": 18,
+                "datapoint_count": 18,
+                "execution_time_millis": 1906,
+            },
+        }
+        try:
+            ExecutionStatusResponse.from_dict(response)
+        except DuneError as err:
+            self.fail(f"Unexpected error {err}")
+
     def test_parse_status_response_completed(self):
         self.assertEqual(
             ExecutionStatusResponse(
@@ -179,6 +212,20 @@ class MyTestCase(unittest.TestCase):
             expected, ResultsResponse.from_dict(self.results_response_data)
         )
 
+    def test_execution_result_csv(self):
+        # document the expected output data from DuneAPI result/csv endpoint
+        csv_response = ExecutionResultCSV(data=self.execution_result_csv_data)
+        result = csv.reader(TextIOWrapper(csv_response.data))
+        # note that CSV is non-typed, up to the reader to do type inference
+        self.assertEqual(
+            [
+                ["TableName", "ct"],
+                ["eth_blocks", "6296"],
+                ["eth_traces", "4474223"],
+            ],
+            [r for r in result],
+        )
+
 
 if __name__ == "__main__":
     unittest.main()
